#
# spec file for package goldpinger
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           goldpinger
Version:        3.10.2
Release:        1.3
Summary:        Tests and displays connectivity between nodes in a Kubernetes cluster
License:        Apache-2.0
URL:            https://github.com/bloomberg/goldpinger
Source:         goldpinger-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.23

%description
Goldpinger makes calls between its instances to monitor your networking. It
runs as a DaemonSet on Kubernetes and produces Prometheus metrics that can be
scraped, visualised and alerted on.

Oh, and it gives you the graph below for your cluster.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.Version=v%{version} \
   -X main.Build=$BUILD_DATE" \
   -o bin/%{name} ./cmd/%{name}

%install
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.10.2:
  * Up the app version
  * Fix typo
  * build with go 1.23
  * update golang.org/x/image to resolve cve-2024-24792
  * Fix datatype
  * Update the chart version
  * fix: move metricRelabelings to correct section
  * improvement: support relabelings in ServiceMonitor
  * Fix small typo i Chart description. Change troublshoot to
    troubleshoot
  * The appVersion should not have a v
  * Update the publishing workflow
  * Secure by default - set the security context and pod security
    context
  * Remove kubernetes version to use the default image
  * Update to kube 1.30 for the kind cluster as well
  * Update the versions to the latest
  * feat: add helm chart
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.10.1:
  * Update the version
  * Upgrade golang to 1.22 and update dependencies
  * Add default namespace `default` to ServiceAccount definition,
    to catch case where users find-replace `default` with another
    namespace but don't change it for the ServiceAccount
* Tue Apr  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.10.0:
  * Increment the version
  * use protobuf and add resourceVersion in listOption
* Thu Nov  9 2023 kastl@b1-systems.de
- Update to version 3.9.0:
  * Use full imags base name as ARG
  * fix dockerfile
  * Provide Windows builds and refactor CI
* Tue Oct 24 2023 kastl@b1-systems.de
- Update to version 3.8.0:
  * OOPS - accidentally left out the target on doing the update
  * Update to golang 1.21 in the github workflow as well
  * Update the builder image and use distroless for the final image
  * :trollface: seriously? how was this broken
  * Update go.sum
  * Update all the dependencies...
  * Remove deprecated rbac.authorization.k8s.io/v1beta1
* Tue Oct 24 2023 Johannes Kastl <kastl@b1-systems.de>
- new package goldpinger: Debugging tool for Kubernetes which tests
  and displays connectivity between nodes in the cluster
